/* contrib/isn/isn--unpackaged--1.0.sql */

-- complain if script is sourced in psql, rather than via CREATE EXTENSION
\echo Use "CREATE EXTENSION isn FROM unpackaged" to load this file. \quit

ALTER EXTENSION isn ADD type ean13;
ALTER EXTENSION isn ADD function ean13_in(cstring);
ALTER EXTENSION isn ADD function ean13_out(ean13);
ALTER EXTENSION isn ADD type isbn13;
ALTER EXTENSION isn ADD function isbn13_in(cstring);
ALTER EXTENSION isn ADD function ean13_out(isbn13);
ALTER EXTENSION isn ADD type ismn13;
ALTER EXTENSION isn ADD function ismn13_in(cstring);
ALTER EXTENSION isn ADD function ean13_out(ismn13);
ALTER EXTENSION isn ADD type issn13;
ALTER EXTENSION isn ADD function issn13_in(cstring);
ALTER EXTENSION isn ADD function ean13_out(issn13);
ALTER EXTENSION isn ADD type isbn;
ALTER EXTENSION isn ADD function isbn_in(cstring);
ALTER EXTENSION isn ADD function isn_out(isbn);
ALTER EXTENSION isn ADD type ismn;
ALTER EXTENSION isn ADD function ismn_in(cstring);
ALTER EXTENSION isn ADD function isn_out(ismn);
ALTER EXTENSION isn ADD type issn;
ALTER EXTENSION isn ADD function issn_in(cstring);
ALTER EXTENSION isn ADD function isn_out(issn);
ALTER EXTENSION isn ADD type upc;
ALTER EXTENSION isn ADD function upc_in(cstring);
ALTER EXTENSION isn ADD function isn_out(upc);
ALTER EXTENSION isn ADD function isnlt(ean13,ean13);
ALTER EXTENSION isn ADD function isnle(ean13,ean13);
ALTER EXTENSION isn ADD function isneq(ean13,ean13);
ALTER EXTENSION isn ADD function isnge(ean13,ean13);
ALTER EXTENSION isn ADD function isngt(ean13,ean13);
ALTER EXTENSION isn ADD function isnne(ean13,ean13);
ALTER EXTENSION isn ADD function isnlt(ean13,isbn13);
ALTER EXTENSION isn ADD function isnle(ean13,isbn13);
ALTER EXTENSION isn ADD function isneq(ean13,isbn13);
ALTER EXTENSION isn ADD function isnge(ean13,isbn13);
ALTER EXTENSION isn ADD function isngt(ean13,isbn13);
ALTER EXTENSION isn ADD function isnne(ean13,isbn13);
ALTER EXTENSION isn ADD function isnlt(ean13,ismn13);
ALTER EXTENSION isn ADD function isnle(ean13,ismn13);
ALTER EXTENSION isn ADD function isneq(ean13,ismn13);
ALTER EXTENSION isn ADD function isnge(ean13,ismn13);
ALTER EXTENSION isn ADD function isngt(ean13,ismn13);
ALTER EXTENSION isn ADD function isnne(ean13,ismn13);
ALTER EXTENSION isn ADD function isnlt(ean13,issn13);
ALTER EXTENSION isn ADD function isnle(ean13,issn13);
ALTER EXTENSION isn ADD function isneq(ean13,issn13);
ALTER EXTENSION isn ADD function isnge(ean13,issn13);
ALTER EXTENSION isn ADD function isngt(ean13,issn13);
ALTER EXTENSION isn ADD function isnne(ean13,issn13);
ALTER EXTENSION isn ADD function isnlt(ean13,isbn);
ALTER EXTENSION isn ADD function isnle(ean13,isbn);
ALTER EXTENSION isn ADD function isneq(ean13,isbn);
ALTER EXTENSION isn ADD function isnge(ean13,isbn);
ALTER EXTENSION isn ADD function isngt(ean13,isbn);
ALTER EXTENSION isn ADD function isnne(ean13,isbn);
ALTER EXTENSION isn ADD function isnlt(ean13,ismn);
ALTER EXTENSION isn ADD function isnle(ean13,ismn);
ALTER EXTENSION isn ADD function isneq(ean13,ismn);
ALTER EXTENSION isn ADD function isnge(ean13,ismn);
ALTER EXTENSION isn ADD function isngt(ean13,ismn);
ALTER EXTENSION isn ADD function isnne(ean13,ismn);
ALTER EXTENSION isn ADD function isnlt(ean13,issn);
ALTER EXTENSION isn ADD function isnle(ean13,issn);
ALTER EXTENSION isn ADD function isneq(ean13,issn);
ALTER EXTENSION isn ADD function isnge(ean13,issn);
ALTER EXTENSION isn ADD function isngt(ean13,issn);
ALTER EXTENSION isn ADD function isnne(ean13,issn);
ALTER EXTENSION isn ADD function isnlt(ean13,upc);
ALTER EXTENSION isn ADD function isnle(ean13,upc);
ALTER EXTENSION isn ADD function isneq(ean13,upc);
ALTER EXTENSION isn ADD function isnge(ean13,upc);
ALTER EXTENSION isn ADD function isngt(ean13,upc);
ALTER EXTENSION isn ADD function isnne(ean13,upc);
ALTER EXTENSION isn ADD function isnlt(isbn13,isbn13);
ALTER EXTENSION isn ADD function isnle(isbn13,isbn13);
ALTER EXTENSION isn ADD function isneq(isbn13,isbn13);
ALTER EXTENSION isn ADD function isnge(isbn13,isbn13);
ALTER EXTENSION isn ADD function isngt(isbn13,isbn13);
ALTER EXTENSION isn ADD function isnne(isbn13,isbn13);
ALTER EXTENSION isn ADD function isnlt(isbn13,isbn);
ALTER EXTENSION isn ADD function isnle(isbn13,isbn);
ALTER EXTENSION isn ADD function isneq(isbn13,isbn);
ALTER EXTENSION isn ADD function isnge(isbn13,isbn);
ALTER EXTENSION isn ADD function isngt(isbn13,isbn);
ALTER EXTENSION isn ADD function isnne(isbn13,isbn);
ALTER EXTENSION isn ADD function isnlt(isbn13,ean13);
ALTER EXTENSION isn ADD function isnle(isbn13,ean13);
ALTER EXTENSION isn ADD function isneq(isbn13,ean13);
ALTER EXTENSION isn ADD function isnge(isbn13,ean13);
ALTER EXTENSION isn ADD function isngt(isbn13,ean13);
ALTER EXTENSION isn ADD function isnne(isbn13,ean13);
ALTER EXTENSION isn ADD function isnlt(isbn,isbn);
ALTER EXTENSION isn ADD function isnle(isbn,isbn);
ALTER EXTENSION isn ADD function isneq(isbn,isbn);
ALTER EXTENSION isn ADD function isnge(isbn,isbn);
ALTER EXTENSION isn ADD function isngt(isbn,isbn);
ALTER EXTENSION isn ADD function isnne(isbn,isbn);
ALTER EXTENSION isn ADD function isnlt(isbn,isbn13);
ALTER EXTENSION isn ADD function isnle(isbn,isbn13);
ALTER EXTENSION isn ADD function isneq(isbn,isbn13);
ALTER EXTENSION isn ADD function isnge(isbn,isbn13);
ALTER EXTENSION isn ADD function isngt(isbn,isbn13);
ALTER EXTENSION isn ADD function isnne(isbn,isbn13);
ALTER EXTENSION isn ADD function isnlt(isbn,ean13);
ALTER EXTENSION isn ADD function isnle(isbn,ean13);
ALTER EXTENSION isn ADD function isneq(isbn,ean13);
ALTER EXTENSION isn ADD function isnge(isbn,ean13);
ALTER EXTENSION isn ADD function isngt(isbn,ean13);
ALTER EXTENSION isn ADD function isnne(isbn,ean13);
ALTER EXTENSION isn ADD function isnlt(ismn13,ismn13);
ALTER EXTENSION isn ADD function isnle(ismn13,ismn13);
ALTER EXTENSION isn ADD function isneq(ismn13,ismn13);
ALTER EXTENSION isn ADD function isnge(ismn13,ismn13);
ALTER EXTENSION isn ADD function isngt(ismn13,ismn13);
ALTER EXTENSION isn ADD function isnne(ismn13,ismn13);
ALTER EXTENSION isn ADD function isnlt(ismn13,ismn);
ALTER EXTENSION isn ADD function isnle(ismn13,ismn);
ALTER EXTENSION isn ADD function isneq(ismn13,ismn);
ALTER EXTENSION isn ADD function isnge(ismn13,ismn);
ALTER EXTENSION isn ADD function isngt(ismn13,ismn);
ALTER EXTENSION isn ADD function isnne(ismn13,ismn);
ALTER EXTENSION isn ADD function isnlt(ismn13,ean13);
ALTER EXTENSION isn ADD function isnle(ismn13,ean13);
ALTER EXTENSION isn ADD function isneq(ismn13,ean13);
ALTER EXTENSION isn ADD function isnge(ismn13,ean13);
ALTER EXTENSION isn ADD function isngt(ismn13,ean13);
ALTER EXTENSION isn ADD function isnne(ismn13,ean13);
ALTER EXTENSION isn ADD function isnlt(ismn,ismn);
ALTER EXTENSION isn ADD function isnle(ismn,ismn);
ALTER EXTENSION isn ADD function isneq(ismn,ismn);
ALTER EXTENSION isn ADD function isnge(ismn,ismn);
ALTER EXTENSION isn ADD function isngt(ismn,ismn);
ALTER EXTENSION isn ADD function isnne(ismn,ismn);
ALTER EXTENSION isn ADD function isnlt(ismn,ismn13);
ALTER EXTENSION isn ADD function isnle(ismn,ismn13);
ALTER EXTENSION isn ADD function isneq(ismn,ismn13);
ALTER EXTENSION isn ADD function isnge(ismn,ismn13);
ALTER EXTENSION isn ADD function isngt(ismn,ismn13);
ALTER EXTENSION isn ADD function isnne(ismn,ismn13);
ALTER EXTENSION isn ADD function isnlt(ismn,ean13);
ALTER EXTENSION isn ADD function isnle(ismn,ean13);
ALTER EXTENSION isn ADD function isneq(ismn,ean13);
ALTER EXTENSION isn ADD function isnge(ismn,ean13);
ALTER EXTENSION isn ADD function isngt(ismn,ean13);
ALTER EXTENSION isn ADD function isnne(ismn,ean13);
ALTER EXTENSION isn ADD function isnlt(issn13,issn13);
ALTER EXTENSION isn ADD function isnle(issn13,issn13);
ALTER EXTENSION isn ADD function isneq(issn13,issn13);
ALTER EXTENSION isn ADD function isnge(issn13,issn13);
ALTER EXTENSION isn ADD function isngt(issn13,issn13);
ALTER EXTENSION isn ADD function isnne(issn13,issn13);
ALTER EXTENSION isn ADD function isnlt(issn13,issn);
ALTER EXTENSION isn ADD function isnle(issn13,issn);
ALTER EXTENSION isn ADD function isneq(issn13,issn);
ALTER EXTENSION isn ADD function isnge(issn13,issn);
ALTER EXTENSION isn ADD function isngt(issn13,issn);
ALTER EXTENSION isn ADD function isnne(issn13,issn);
ALTER EXTENSION isn ADD function isnlt(issn13,ean13);
ALTER EXTENSION isn ADD function isnle(issn13,ean13);
ALTER EXTENSION isn ADD function isneq(issn13,ean13);
ALTER EXTENSION isn ADD function isnge(issn13,ean13);
ALTER EXTENSION isn ADD function isngt(issn13,ean13);
ALTER EXTENSION isn ADD function isnne(issn13,ean13);
ALTER EXTENSION isn ADD function isnlt(issn,issn);
ALTER EXTENSION isn ADD function isnle(issn,issn);
ALTER EXTENSION isn ADD function isneq(issn,issn);
ALTER EXTENSION isn ADD function isnge(issn,issn);
ALTER EXTENSION isn ADD function isngt(issn,issn);
ALTER EXTENSION isn ADD function isnne(issn,issn);
ALTER EXTENSION isn ADD function isnlt(issn,issn13);
ALTER EXTENSION isn ADD function isnle(issn,issn13);
ALTER EXTENSION isn ADD function isneq(issn,issn13);
ALTER EXTENSION isn ADD function isnge(issn,issn13);
ALTER EXTENSION isn ADD function isngt(issn,issn13);
ALTER EXTENSION isn ADD function isnne(issn,issn13);
ALTER EXTENSION isn ADD function isnlt(issn,ean13);
ALTER EXTENSION isn ADD function isnle(issn,ean13);
ALTER EXTENSION isn ADD function isneq(issn,ean13);
ALTER EXTENSION isn ADD function isnge(issn,ean13);
ALTER EXTENSION isn ADD function isngt(issn,ean13);
ALTER EXTENSION isn ADD function isnne(issn,ean13);
ALTER EXTENSION isn ADD function isnlt(upc,upc);
ALTER EXTENSION isn ADD function isnle(upc,upc);
ALTER EXTENSION isn ADD function isneq(upc,upc);
ALTER EXTENSION isn ADD function isnge(upc,upc);
ALTER EXTENSION isn ADD function isngt(upc,upc);
ALTER EXTENSION isn ADD function isnne(upc,upc);
ALTER EXTENSION isn ADD function isnlt(upc,ean13);
ALTER EXTENSION isn ADD function isnle(upc,ean13);
ALTER EXTENSION isn ADD function isneq(upc,ean13);
ALTER EXTENSION isn ADD function isnge(upc,ean13);
ALTER EXTENSION isn ADD function isngt(upc,ean13);
ALTER EXTENSION isn ADD function isnne(upc,ean13);
ALTER EXTENSION isn ADD operator >(ean13,ean13);
ALTER EXTENSION isn ADD operator >=(ean13,ean13);
ALTER EXTENSION isn ADD operator <(ean13,ean13);
ALTER EXTENSION isn ADD operator <=(ean13,ean13);
ALTER EXTENSION isn ADD operator <>(ean13,ean13);
ALTER EXTENSION isn ADD operator =(ean13,ean13);
ALTER EXTENSION isn ADD operator >(isbn13,ean13);
ALTER EXTENSION isn ADD operator >=(ean13,isbn13);
ALTER EXTENSION isn ADD operator <(ean13,isbn13);
ALTER EXTENSION isn ADD operator >=(isbn13,ean13);
ALTER EXTENSION isn ADD operator >(ean13,isbn13);
ALTER EXTENSION isn ADD operator <=(ean13,isbn13);
ALTER EXTENSION isn ADD operator =(isbn13,ean13);
ALTER EXTENSION isn ADD operator <>(ean13,isbn13);
ALTER EXTENSION isn ADD operator =(ean13,isbn13);
ALTER EXTENSION isn ADD operator <=(isbn13,ean13);
ALTER EXTENSION isn ADD operator <(isbn13,ean13);
ALTER EXTENSION isn ADD operator <>(isbn13,ean13);
ALTER EXTENSION isn ADD operator >(ismn13,ean13);
ALTER EXTENSION isn ADD operator >=(ean13,ismn13);
ALTER EXTENSION isn ADD operator <(ean13,ismn13);
ALTER EXTENSION isn ADD operator >=(ismn13,ean13);
ALTER EXTENSION isn ADD operator >(ean13,ismn13);
ALTER EXTENSION isn ADD operator <=(ean13,ismn13);
ALTER EXTENSION isn ADD operator =(ismn13,ean13);
ALTER EXTENSION isn ADD operator <>(ean13,ismn13);
ALTER EXTENSION isn ADD operator =(ean13,ismn13);
ALTER EXTENSION isn ADD operator <=(ismn13,ean13);
ALTER EXTENSION isn ADD operator <(ismn13,ean13);
ALTER EXTENSION isn ADD operator <>(ismn13,ean13);
ALTER EXTENSION isn ADD operator >(issn13,ean13);
ALTER EXTENSION isn ADD operator >=(ean13,issn13);
ALTER EXTENSION isn ADD operator <(ean13,issn13);
ALTER EXTENSION isn ADD operator >=(issn13,ean13);
ALTER EXTENSION isn ADD operator >(ean13,issn13);
ALTER EXTENSION isn ADD operator <=(ean13,issn13);
ALTER EXTENSION isn ADD operator =(issn13,ean13);
ALTER EXTENSION isn ADD operator <>(ean13,issn13);
ALTER EXTENSION isn ADD operator =(ean13,issn13);
ALTER EXTENSION isn ADD operator <=(issn13,ean13);
ALTER EXTENSION isn ADD operator <(issn13,ean13);
ALTER EXTENSION isn ADD operator <>(issn13,ean13);
ALTER EXTENSION isn ADD operator >(isbn,ean13);
ALTER EXTENSION isn ADD operator >=(ean13,isbn);
ALTER EXTENSION isn ADD operator <(ean13,isbn);
ALTER EXTENSION isn ADD operator >=(isbn,ean13);
ALTER EXTENSION isn ADD operator >(ean13,isbn);
ALTER EXTENSION isn ADD operator <=(ean13,isbn);
ALTER EXTENSION isn ADD operator =(isbn,ean13);
ALTER EXTENSION isn ADD operator <>(ean13,isbn);
ALTER EXTENSION isn ADD operator =(ean13,isbn);
ALTER EXTENSION isn ADD operator <=(isbn,ean13);
ALTER EXTENSION isn ADD operator <(isbn,ean13);
ALTER EXTENSION isn ADD operator <>(isbn,ean13);
ALTER EXTENSION isn ADD operator >(ismn,ean13);
ALTER EXTENSION isn ADD operator >=(ean13,ismn);
ALTER EXTENSION isn ADD operator <(ean13,ismn);
ALTER EXTENSION isn ADD operator >=(ismn,ean13);
ALTER EXTENSION isn ADD operator >(ean13,ismn);
ALTER EXTENSION isn ADD operator <=(ean13,ismn);
ALTER EXTENSION isn ADD operator =(ismn,ean13);
ALTER EXTENSION isn ADD operator <>(ean13,ismn);
ALTER EXTENSION isn ADD operator =(ean13,ismn);
ALTER EXTENSION isn ADD operator <=(ismn,ean13);
ALTER EXTENSION isn ADD operator <(ismn,ean13);
ALTER EXTENSION isn ADD operator <>(ismn,ean13);
ALTER EXTENSION isn ADD operator >(issn,ean13);
ALTER EXTENSION isn ADD operator >=(ean13,issn);
ALTER EXTENSION isn ADD operator <(ean13,issn);
ALTER EXTENSION isn ADD operator >=(issn,ean13);
ALTER EXTENSION isn ADD operator >(ean13,issn);
ALTER EXTENSION isn ADD operator <=(ean13,issn);
ALTER EXTENSION isn ADD operator =(issn,ean13);
ALTER EXTENSION isn ADD operator <>(ean13,issn);
ALTER EXTENSION isn ADD operator =(ean13,issn);
ALTER EXTENSION isn ADD operator <=(issn,ean13);
ALTER EXTENSION isn ADD operator <(issn,ean13);
ALTER EXTENSION isn ADD operator <>(issn,ean13);
ALTER EXTENSION isn ADD operator >(upc,ean13);
ALTER EXTENSION isn ADD operator >=(ean13,upc);
ALTER EXTENSION isn ADD operator <(ean13,upc);
ALTER EXTENSION isn ADD operator >=(upc,ean13);
ALTER EXTENSION isn ADD operator >(ean13,upc);
ALTER EXTENSION isn ADD operator <=(ean13,upc);
ALTER EXTENSION isn ADD operator =(upc,ean13);
ALTER EXTENSION isn ADD operator <>(ean13,upc);
ALTER EXTENSION isn ADD operator =(ean13,upc);
ALTER EXTENSION isn ADD operator <=(upc,ean13);
ALTER EXTENSION isn ADD operator <(upc,ean13);
ALTER EXTENSION isn ADD operator <>(upc,ean13);
ALTER EXTENSION isn ADD operator >(isbn13,isbn13);
ALTER EXTENSION isn ADD operator >=(isbn13,isbn13);
ALTER EXTENSION isn ADD operator <(isbn13,isbn13);
ALTER EXTENSION isn ADD operator <=(isbn13,isbn13);
ALTER EXTENSION isn ADD operator <>(isbn13,isbn13);
ALTER EXTENSION isn ADD operator =(isbn13,isbn13);
ALTER EXTENSION isn ADD operator >(isbn,isbn13);
ALTER EXTENSION isn ADD operator >=(isbn13,isbn);
ALTER EXTENSION isn ADD operator <(isbn13,isbn);
ALTER EXTENSION isn ADD operator >=(isbn,isbn13);
ALTER EXTENSION isn ADD operator >(isbn13,isbn);
ALTER EXTENSION isn ADD operator <=(isbn13,isbn);
ALTER EXTENSION isn ADD operator =(isbn,isbn13);
ALTER EXTENSION isn ADD operator <>(isbn13,isbn);
ALTER EXTENSION isn ADD operator =(isbn13,isbn);
ALTER EXTENSION isn ADD operator <=(isbn,isbn13);
ALTER EXTENSION isn ADD operator <(isbn,isbn13);
ALTER EXTENSION isn ADD operator <>(isbn,isbn13);
ALTER EXTENSION isn ADD operator >(isbn,isbn);
ALTER EXTENSION isn ADD operator >=(isbn,isbn);
ALTER EXTENSION isn ADD operator <(isbn,isbn);
ALTER EXTENSION isn ADD operator <=(isbn,isbn);
ALTER EXTENSION isn ADD operator <>(isbn,isbn);
ALTER EXTENSION isn ADD operator =(isbn,isbn);
ALTER EXTENSION isn ADD operator >(ismn13,ismn13);
ALTER EXTENSION isn ADD operator >=(ismn13,ismn13);
ALTER EXTENSION isn ADD operator <(ismn13,ismn13);
ALTER EXTENSION isn ADD operator <=(ismn13,ismn13);
ALTER EXTENSION isn ADD operator <>(ismn13,ismn13);
ALTER EXTENSION isn ADD operator =(ismn13,ismn13);
ALTER EXTENSION isn ADD operator >(ismn,ismn13);
ALTER EXTENSION isn ADD operator >=(ismn13,ismn);
ALTER EXTENSION isn ADD operator <(ismn13,ismn);
ALTER EXTENSION isn ADD operator >=(ismn,ismn13);
ALTER EXTENSION isn ADD operator >(ismn13,ismn);
ALTER EXTENSION isn ADD operator <=(ismn13,ismn);
ALTER EXTENSION isn ADD operator =(ismn,ismn13);
ALTER EXTENSION isn ADD operator <>(ismn13,ismn);
ALTER EXTENSION isn ADD operator =(ismn13,ismn);
ALTER EXTENSION isn ADD operator <=(ismn,ismn13);
ALTER EXTENSION isn ADD operator <(ismn,ismn13);
ALTER EXTENSION isn ADD operator <>(ismn,ismn13);
ALTER EXTENSION isn ADD operator >(ismn,ismn);
ALTER EXTENSION isn ADD operator >=(ismn,ismn);
ALTER EXTENSION isn ADD operator <(ismn,ismn);
ALTER EXTENSION isn ADD operator <=(ismn,ismn);
ALTER EXTENSION isn ADD operator <>(ismn,ismn);
ALTER EXTENSION isn ADD operator =(ismn,ismn);
ALTER EXTENSION isn ADD operator >(issn13,issn13);
ALTER EXTENSION isn ADD operator >=(issn13,issn13);
ALTER EXTENSION isn ADD operator <(issn13,issn13);
ALTER EXTENSION isn ADD operator <=(issn13,issn13);
ALTER EXTENSION isn ADD operator <>(issn13,issn13);
ALTER EXTENSION isn ADD operator =(issn13,issn13);
ALTER EXTENSION isn ADD operator >(issn,issn13);
ALTER EXTENSION isn ADD operator >=(issn13,issn);
ALTER EXTENSION isn ADD operator <(issn13,issn);
ALTER EXTENSION isn ADD operator >=(issn,issn13);
ALTER EXTENSION isn ADD operator >(issn13,issn);
ALTER EXTENSION isn ADD operator <=(issn13,issn);
ALTER EXTENSION isn ADD operator =(issn,issn13);
ALTER EXTENSION isn ADD operator <>(issn13,issn);
ALTER EXTENSION isn ADD operator =(issn13,issn);
ALTER EXTENSION isn ADD operator <=(issn,issn13);
ALTER EXTENSION isn ADD operator <(issn,issn13);
ALTER EXTENSION isn ADD operator <>(issn,issn13);
ALTER EXTENSION isn ADD operator >(issn,issn);
ALTER EXTENSION isn ADD operator >=(issn,issn);
ALTER EXTENSION isn ADD operator <(issn,issn);
ALTER EXTENSION isn ADD operator <=(issn,issn);
ALTER EXTENSION isn ADD operator <>(issn,issn);
ALTER EXTENSION isn ADD operator =(issn,issn);
ALTER EXTENSION isn ADD operator >(upc,upc);
ALTER EXTENSION isn ADD operator >=(upc,upc);
ALTER EXTENSION isn ADD operator <(upc,upc);
ALTER EXTENSION isn ADD operator <=(upc,upc);
ALTER EXTENSION isn ADD operator <>(upc,upc);
ALTER EXTENSION isn ADD operator =(upc,upc);
ALTER EXTENSION isn ADD operator family isn_ops using btree;
ALTER EXTENSION isn ADD operator family isn_ops using hash;
ALTER EXTENSION isn ADD function btean13cmp(ean13,ean13);
ALTER EXTENSION isn ADD operator class ean13_ops using btree;
ALTER EXTENSION isn ADD function hashean13(ean13);
ALTER EXTENSION isn ADD operator class ean13_ops using hash;
ALTER EXTENSION isn ADD function btean13cmp(ean13,isbn13);
ALTER EXTENSION isn ADD function btean13cmp(ean13,ismn13);
ALTER EXTENSION isn ADD function btean13cmp(ean13,issn13);
ALTER EXTENSION isn ADD function btean13cmp(ean13,isbn);
ALTER EXTENSION isn ADD function btean13cmp(ean13,ismn);
ALTER EXTENSION isn ADD function btean13cmp(ean13,issn);
ALTER EXTENSION isn ADD function btean13cmp(ean13,upc);
ALTER EXTENSION isn ADD function btisbn13cmp(isbn13,isbn13);
ALTER EXTENSION isn ADD operator class isbn13_ops using btree;
ALTER EXTENSION isn ADD function hashisbn13(isbn13);
ALTER EXTENSION isn ADD operator class isbn13_ops using hash;
ALTER EXTENSION isn ADD function btisbn13cmp(isbn13,ean13);
ALTER EXTENSION isn ADD function btisbn13cmp(isbn13,isbn);
ALTER EXTENSION isn ADD function btisbncmp(isbn,isbn);
ALTER EXTENSION isn ADD operator class isbn_ops using btree;
ALTER EXTENSION isn ADD function hashisbn(isbn);
ALTER EXTENSION isn ADD operator class isbn_ops using hash;
ALTER EXTENSION isn ADD function btisbncmp(isbn,ean13);
ALTER EXTENSION isn ADD function btisbncmp(isbn,isbn13);
ALTER EXTENSION isn ADD function btismn13cmp(ismn13,ismn13);
ALTER EXTENSION isn ADD operator class ismn13_ops using btree;
ALTER EXTENSION isn ADD function hashismn13(ismn13);
ALTER EXTENSION isn ADD operator class ismn13_ops using hash;
ALTER EXTENSION isn ADD function btismn13cmp(ismn13,ean13);
ALTER EXTENSION isn ADD function btismn13cmp(ismn13,ismn);
ALTER EXTENSION isn ADD function btismncmp(ismn,ismn);
ALTER EXTENSION isn ADD operator class ismn_ops using btree;
ALTER EXTENSION isn ADD function hashismn(ismn);
ALTER EXTENSION isn ADD operator class ismn_ops using hash;
ALTER EXTENSION isn ADD function btismncmp(ismn,ean13);
ALTER EXTENSION isn ADD function btismncmp(ismn,ismn13);
ALTER EXTENSION isn ADD function btissn13cmp(issn13,issn13);
ALTER EXTENSION isn ADD operator class issn13_ops using btree;
ALTER EXTENSION isn ADD function hashissn13(issn13);
ALTER EXTENSION isn ADD operator class issn13_ops using hash;
ALTER EXTENSION isn ADD function btissn13cmp(issn13,ean13);
ALTER EXTENSION isn ADD function btissn13cmp(issn13,issn);
ALTER EXTENSION isn ADD function btissncmp(issn,issn);
ALTER EXTENSION isn ADD operator class issn_ops using btree;
ALTER EXTENSION isn ADD function hashissn(issn);
ALTER EXTENSION isn ADD operator class issn_ops using hash;
ALTER EXTENSION isn ADD function btissncmp(issn,ean13);
ALTER EXTENSION isn ADD function btissncmp(issn,issn13);
ALTER EXTENSION isn ADD function btupccmp(upc,upc);
ALTER EXTENSION isn ADD operator class upc_ops using btree;
ALTER EXTENSION isn ADD function hashupc(upc);
ALTER EXTENSION isn ADD operator class upc_ops using hash;
ALTER EXTENSION isn ADD function btupccmp(upc,ean13);
ALTER EXTENSION isn ADD function isbn13(ean13);
ALTER EXTENSION isn ADD function ismn13(ean13);
ALTER EXTENSION isn ADD function issn13(ean13);
ALTER EXTENSION isn ADD function isbn(ean13);
ALTER EXTENSION isn ADD function ismn(ean13);
ALTER EXTENSION isn ADD function issn(ean13);
ALTER EXTENSION isn ADD function upc(ean13);
ALTER EXTENSION isn ADD cast (ean13 as isbn13);
ALTER EXTENSION isn ADD cast (ean13 as isbn);
ALTER EXTENSION isn ADD cast (ean13 as ismn13);
ALTER EXTENSION isn ADD cast (ean13 as ismn);
ALTER EXTENSION isn ADD cast (ean13 as issn13);
ALTER EXTENSION isn ADD cast (ean13 as issn);
ALTER EXTENSION isn ADD cast (ean13 as upc);
ALTER EXTENSION isn ADD cast (isbn13 as ean13);
ALTER EXTENSION isn ADD cast (isbn as ean13);
ALTER EXTENSION isn ADD cast (ismn13 as ean13);
ALTER EXTENSION isn ADD cast (ismn as ean13);
ALTER EXTENSION isn ADD cast (issn13 as ean13);
ALTER EXTENSION isn ADD cast (issn as ean13);
ALTER EXTENSION isn ADD cast (upc as ean13);
ALTER EXTENSION isn ADD cast (isbn as isbn13);
ALTER EXTENSION isn ADD cast (isbn13 as isbn);
ALTER EXTENSION isn ADD cast (ismn as ismn13);
ALTER EXTENSION isn ADD cast (ismn13 as ismn);
ALTER EXTENSION isn ADD cast (issn as issn13);
ALTER EXTENSION isn ADD cast (issn13 as issn);
ALTER EXTENSION isn ADD function make_valid(ean13);
ALTER EXTENSION isn ADD function make_valid(isbn13);
ALTER EXTENSION isn ADD function make_valid(ismn13);
ALTER EXTENSION isn ADD function make_valid(issn13);
ALTER EXTENSION isn ADD function make_valid(isbn);
ALTER EXTENSION isn ADD function make_valid(ismn);
ALTER EXTENSION isn ADD function make_valid(issn);
ALTER EXTENSION isn ADD function make_valid(upc);
ALTER EXTENSION isn ADD function is_valid(ean13);
ALTER EXTENSION isn ADD function is_valid(isbn13);
ALTER EXTENSION isn ADD function is_valid(ismn13);
ALTER EXTENSION isn ADD function is_valid(issn13);
ALTER EXTENSION isn ADD function is_valid(isbn);
ALTER EXTENSION isn ADD function is_valid(ismn);
ALTER EXTENSION isn ADD function is_valid(issn);
ALTER EXTENSION isn ADD function is_valid(upc);
ALTER EXTENSION isn ADD function isn_weak(boolean);
ALTER EXTENSION isn ADD function isn_weak();
